@@ -9,7 +9,7 @@
 
 package Glib::GenPod;
 
-our $VERSION = '1.308';
+our $VERSION = '1.324';
 
 use strict;
 use warnings;
@@ -278,7 +278,14 @@ sub xsdoc2pod
 		# end.  But all the other =head1 below need a closing =cut.
 
 		print "=head1 NAME\n\n$package";
-		print ' - '.$pkgdata->{blurb} if (exists ($pkgdata->{blurb}));
+		if (exists ($pkgdata->{blurb})) {
+			print ' - '.$pkgdata->{blurb};
+		} else {
+			my $cname = convert_to_cname ($package);
+			if (defined $cname) {
+				print " - wrapper for $cname";
+			}
+		}
 		print "\n\n=cut\n\n";
 
 		#                   pods            , position 
@@ -448,6 +455,8 @@ our %basic_types = (
 	gchar_length => 'string',
 	gchar_utf8_length => 'string',
 
+	char_byte => 'byte string',
+
 	FILE => 'file handle',
 	time_t => 'unix timestamp',
 
@@ -708,7 +717,7 @@ sub podify_signals {
 	my @sigs = Glib::Type->list_signals (shift);
 	return undef unless @sigs;
 	$str = "=over\n\n";
-	foreach (@sigs) {
+	foreach (sort {$a->{signal_name} cmp $b->{signal_name} } @sigs) {
 		$str .= '=item ';
 		$str .= convert_type ($_->{return_type}).' = '
 			if exists $_->{return_type};
@@ -868,7 +877,7 @@ pod will be still be placed there.
 This function is called at all of the specified points through out the process
 of generating pod for a page. Any pod matching the I<position> passed will be
 returned, undef if no matches were found.  If I<position> is undef all pods
-without sepcific postion information will be returned. I<pods> is a reference
+without specific position information will be returned. I<pods> is a reference
 to an array of pod hashes.
 
 =over
@@ -1117,7 +1126,7 @@ So, in general, you will want to specify at least one of these, so that you
 don't credit your work to us under the LGPL.
 
 To set them do something similar to the following in the first part of your
-postamble section in Makefile.PL.  All occurences of <br> in the copyright
+postamble section in Makefile.PL.  All occurrences of <br> in the copyright
 are replaced with newlines, to make it easier to put in a multi-line string.
 
   POD_SET=Glib::GenPod::set_copyright(qq{Copyright 1999 team-foobar<br>LGPL});
@@ -1522,6 +1531,22 @@ sub mkdir_p {
 	} while (@dirs);
 }
 
+sub convert_to_cname {
+	my $perlname = shift;
+	my $cname = $perlname;
+	$cname =~ s/^Gtk2::Gdk::/Gdk/;
+	$cname =~ s/^Gtk2::/Gtk/;
+	$cname =~ s/^Gnome2::Bonobo::/Bonobo/;
+	$cname =~ s/^Gnome2::/Gnome/;
+	$cname =~ s/:://g;
+	my $tmp;
+	eval { $tmp = Glib::Type->package_from_cname($cname); };
+	if ($@ || $tmp ne $perlname) {
+		return;
+	}
+	return $cname;
+}
+
 1;
 __END__
 
